/***********************************************************************
*
**
*        Automatic header module from ASNTOOL
*
************************************************************************/

#ifndef _ASNTOOL_
#include <asn.h>
#endif

static char * asnfilename = "asnfeat.h13";
static AsnValxNode avnx[201] = {
    {2,NULL,0,0.0,NULL } ,
    {20,"other" ,0,0.0,&avnx[2] } ,
    {20,"family" ,1,0.0,&avnx[3] } ,
    {20,"order" ,2,0.0,&avnx[4] } ,
    {20,"class" ,3,0.0,NULL } ,
    {20,"strain" ,2,0.0,&avnx[6] } ,
    {20,"substrain" ,3,0.0,&avnx[7] } ,
    {20,"type" ,4,0.0,&avnx[8] } ,
    {20,"subtype" ,5,0.0,&avnx[9] } ,
    {20,"variety" ,6,0.0,&avnx[10] } ,
    {20,"serotype" ,7,0.0,&avnx[11] } ,
    {20,"serogroup" ,8,0.0,&avnx[12] } ,
    {20,"serovar" ,9,0.0,&avnx[13] } ,
    {20,"cultivar" ,10,0.0,&avnx[14] } ,
    {20,"pathovar" ,11,0.0,&avnx[15] } ,
    {20,"chemovar" ,12,0.0,&avnx[16] } ,
    {20,"biovar" ,13,0.0,&avnx[17] } ,
    {20,"biotype" ,14,0.0,&avnx[18] } ,
    {20,"group" ,15,0.0,&avnx[19] } ,
    {20,"subgroup" ,16,0.0,&avnx[20] } ,
    {20,"isolate" ,17,0.0,&avnx[21] } ,
    {20,"common" ,18,0.0,&avnx[22] } ,
    {20,"acronym" ,19,0.0,&avnx[23] } ,
    {20,"dosage" ,20,0.0,&avnx[24] } ,
    {20,"nat-host" ,21,0.0,&avnx[25] } ,
    {20,"sub-species" ,22,0.0,&avnx[26] } ,
    {20,"specimen-voucher" ,23,0.0,&avnx[27] } ,
    {20,"authority" ,24,0.0,&avnx[28] } ,
    {20,"forma" ,25,0.0,&avnx[29] } ,
    {20,"forma-specialis" ,26,0.0,&avnx[30] } ,
    {20,"ecotype" ,27,0.0,&avnx[31] } ,
    {20,"synonym" ,28,0.0,&avnx[32] } ,
    {20,"anamorph" ,29,0.0,&avnx[33] } ,
    {20,"teleomorph" ,30,0.0,&avnx[34] } ,
    {20,"breed" ,31,0.0,&avnx[35] } ,
    {20,"gb-acronym" ,32,0.0,&avnx[36] } ,
    {20,"gb-anamorph" ,33,0.0,&avnx[37] } ,
    {20,"gb-synonym" ,34,0.0,&avnx[38] } ,
    {20,"old-lineage" ,253,0.0,&avnx[39] } ,
    {20,"old-name" ,254,0.0,&avnx[40] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"not-set" ,0,0.0,&avnx[42] } ,
    {20,"one" ,1,0.0,&avnx[43] } ,
    {20,"two" ,2,0.0,&avnx[44] } ,
    {20,"three" ,3,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"not-set" ,0,0.0,&avnx[47] } ,
    {20,"preprotein" ,1,0.0,&avnx[48] } ,
    {20,"mature" ,2,0.0,&avnx[49] } ,
    {20,"signal-peptide" ,3,0.0,&avnx[50] } ,
    {20,"transit-peptide" ,4,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[53] } ,
    {20,"premsg" ,1,0.0,&avnx[54] } ,
    {20,"mRNA" ,2,0.0,&avnx[55] } ,
    {20,"tRNA" ,3,0.0,&avnx[56] } ,
    {20,"rRNA" ,4,0.0,&avnx[57] } ,
    {20,"snRNA" ,5,0.0,&avnx[58] } ,
    {20,"scRNA" ,6,0.0,&avnx[59] } ,
    {20,"snoRNA" ,7,0.0,&avnx[60] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"disulfide" ,1,0.0,&avnx[62] } ,
    {20,"thiolester" ,2,0.0,&avnx[63] } ,
    {20,"xlink" ,3,0.0,&avnx[64] } ,
    {20,"thioether" ,4,0.0,&avnx[65] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"active" ,1,0.0,&avnx[67] } ,
    {20,"binding" ,2,0.0,&avnx[68] } ,
    {20,"cleavage" ,3,0.0,&avnx[69] } ,
    {20,"inhibit" ,4,0.0,&avnx[70] } ,
    {20,"modified" ,5,0.0,&avnx[71] } ,
    {20,"glycosylation" ,6,0.0,&avnx[72] } ,
    {20,"myristoylation" ,7,0.0,&avnx[73] } ,
    {20,"mutagenized" ,8,0.0,&avnx[74] } ,
    {20,"metal-binding" ,9,0.0,&avnx[75] } ,
    {20,"phosphorylation" ,10,0.0,&avnx[76] } ,
    {20,"acetylation" ,11,0.0,&avnx[77] } ,
    {20,"amidation" ,12,0.0,&avnx[78] } ,
    {20,"methylation" ,13,0.0,&avnx[79] } ,
    {20,"hydroxylation" ,14,0.0,&avnx[80] } ,
    {20,"sulfatation" ,15,0.0,&avnx[81] } ,
    {20,"oxidative-deamination" ,16,0.0,&avnx[82] } ,
    {20,"pyrrolidone-carboxylic-acid" ,17,0.0,&avnx[83] } ,
    {20,"gamma-carboxyglutamic-acid" ,18,0.0,&avnx[84] } ,
    {20,"blocked" ,19,0.0,&avnx[85] } ,
    {20,"lipid-binding" ,20,0.0,&avnx[86] } ,
    {20,"np-binding" ,21,0.0,&avnx[87] } ,
    {20,"dna-binding" ,22,0.0,&avnx[88] } ,
    {20,"signal-peptide" ,23,0.0,&avnx[89] } ,
    {20,"transit-peptide" ,24,0.0,&avnx[90] } ,
    {20,"transmembrane-region" ,25,0.0,&avnx[91] } ,
    {20,"nitrosylation" ,26,0.0,&avnx[92] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[94] } ,
    {20,"pol1" ,1,0.0,&avnx[95] } ,
    {20,"pol2" ,2,0.0,&avnx[96] } ,
    {20,"pol3" ,3,0.0,&avnx[97] } ,
    {20,"bacterial" ,4,0.0,&avnx[98] } ,
    {20,"viral" ,5,0.0,&avnx[99] } ,
    {20,"rna" ,6,0.0,&avnx[100] } ,
    {20,"organelle" ,7,0.0,&avnx[101] } ,
    {20,"other" ,255,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[105] } ,
    {20,"single" ,1,0.0,&avnx[106] } ,
    {20,"multiple" ,2,0.0,&avnx[107] } ,
    {20,"region" ,3,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[109] } ,
    {20,"rna-seq" ,1,0.0,&avnx[110] } ,
    {20,"rna-size" ,2,0.0,&avnx[111] } ,
    {20,"np-map" ,3,0.0,&avnx[112] } ,
    {20,"np-size" ,4,0.0,&avnx[113] } ,
    {20,"pe-seq" ,5,0.0,&avnx[114] } ,
    {20,"cDNA-seq" ,6,0.0,&avnx[115] } ,
    {20,"pe-map" ,7,0.0,&avnx[116] } ,
    {20,"pe-size" ,8,0.0,&avnx[117] } ,
    {20,"pseudo-seq" ,9,0.0,&avnx[118] } ,
    {20,"rev-pe-map" ,10,0.0,&avnx[119] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[121] } ,
    {20,"physiological" ,1,0.0,&avnx[122] } ,
    {20,"in-vitro" ,2,0.0,&avnx[123] } ,
    {20,"oocyte" ,3,0.0,&avnx[124] } ,
    {20,"transfection" ,4,0.0,&avnx[125] } ,
    {20,"transgenic" ,5,0.0,&avnx[126] } ,
    {20,"other" ,255,0.0,NULL } ,
    {3,NULL,1,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {2,NULL,0,0.0,NULL } ,
    {20,"helix" ,1,0.0,&avnx[131] } ,
    {20,"sheet" ,2,0.0,&avnx[132] } ,
    {20,"turn" ,3,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[134] } ,
    {20,"genomic" ,1,0.0,&avnx[135] } ,
    {20,"chloroplast" ,2,0.0,&avnx[136] } ,
    {20,"chromoplast" ,3,0.0,&avnx[137] } ,
    {20,"kinetoplast" ,4,0.0,&avnx[138] } ,
    {20,"mitochondrion" ,5,0.0,&avnx[139] } ,
    {20,"plastid" ,6,0.0,&avnx[140] } ,
    {20,"macronuclear" ,7,0.0,&avnx[141] } ,
    {20,"extrachrom" ,8,0.0,&avnx[142] } ,
    {20,"plasmid" ,9,0.0,&avnx[143] } ,
    {20,"transposon" ,10,0.0,&avnx[144] } ,
    {20,"insertion-seq" ,11,0.0,&avnx[145] } ,
    {20,"cyanelle" ,12,0.0,&avnx[146] } ,
    {20,"proviral" ,13,0.0,&avnx[147] } ,
    {20,"virion" ,14,0.0,&avnx[148] } ,
    {20,"nucleomorph" ,15,0.0,&avnx[149] } ,
    {20,"apicoplast" ,16,0.0,&avnx[150] } ,
    {20,"leucoplast" ,17,0.0,&avnx[151] } ,
    {20,"proplastid" ,18,0.0,&avnx[152] } ,
    {20,"endogenous-virus" ,19,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"unknown" ,0,0.0,&avnx[155] } ,
    {20,"natural" ,1,0.0,&avnx[156] } ,
    {20,"natmut" ,2,0.0,&avnx[157] } ,
    {20,"mut" ,3,0.0,&avnx[158] } ,
    {20,"artificial" ,4,0.0,&avnx[159] } ,
    {20,"synthetic" ,5,0.0,&avnx[160] } ,
    {20,"other" ,255,0.0,NULL } ,
    {3,NULL,0,0.0,NULL } ,
    {20,"chromosome" ,1,0.0,&avnx[163] } ,
    {20,"map" ,2,0.0,&avnx[164] } ,
    {20,"clone" ,3,0.0,&avnx[165] } ,
    {20,"subclone" ,4,0.0,&avnx[166] } ,
    {20,"haplotype" ,5,0.0,&avnx[167] } ,
    {20,"genotype" ,6,0.0,&avnx[168] } ,
    {20,"sex" ,7,0.0,&avnx[169] } ,
    {20,"cell-line" ,8,0.0,&avnx[170] } ,
    {20,"cell-type" ,9,0.0,&avnx[171] } ,
    {20,"tissue-type" ,10,0.0,&avnx[172] } ,
    {20,"clone-lib" ,11,0.0,&avnx[173] } ,
    {20,"dev-stage" ,12,0.0,&avnx[174] } ,
    {20,"frequency" ,13,0.0,&avnx[175] } ,
    {20,"germline" ,14,0.0,&avnx[176] } ,
    {20,"rearranged" ,15,0.0,&avnx[177] } ,
    {20,"lab-host" ,16,0.0,&avnx[178] } ,
    {20,"pop-variant" ,17,0.0,&avnx[179] } ,
    {20,"tissue-lib" ,18,0.0,&avnx[180] } ,
    {20,"plasmid-name" ,19,0.0,&avnx[181] } ,
    {20,"transposon-name" ,20,0.0,&avnx[182] } ,
    {20,"insertion-seq-name" ,21,0.0,&avnx[183] } ,
    {20,"plastid-name" ,22,0.0,&avnx[184] } ,
    {20,"country" ,23,0.0,&avnx[185] } ,
    {20,"segment" ,24,0.0,&avnx[186] } ,
    {20,"endogenous-virus-name" ,25,0.0,&avnx[187] } ,
    {20,"transgenic" ,26,0.0,&avnx[188] } ,
    {20,"environmental-sample" ,27,0.0,&avnx[189] } ,
    {20,"isolation-source" ,28,0.0,&avnx[190] } ,
    {20,"lat-lon" ,29,0.0,&avnx[191] } ,
    {20,"collection-date" ,30,0.0,&avnx[192] } ,
    {20,"collected-by" ,31,0.0,&avnx[193] } ,
    {20,"identified-by" ,32,0.0,&avnx[194] } ,
    {20,"fwd-primer-seq" ,33,0.0,&avnx[195] } ,
    {20,"rev-primer-seq" ,34,0.0,&avnx[196] } ,
    {20,"fwd-primer-name" ,35,0.0,&avnx[197] } ,
    {20,"rev-primer-name" ,36,0.0,&avnx[198] } ,
    {20,"other" ,255,0.0,NULL } ,
    {20,"experimental" ,1,0.0,&avnx[200] } ,
    {20,"not-experimental" ,2,0.0,NULL } };

static AsnType atx[238] = {
  {401, "Seq-feat" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[1],0,&atx[2]} ,
  {0, "id" ,128,0,0,1,0,0,0,0,NULL,&atx[2],NULL,0,&atx[12]} ,
  {402, "Feat-id" ,1,0,0,0,0,1,0,0,NULL,&atx[11],&atx[3],0,&atx[85]} ,
  {0, "gibb" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[5]} ,
  {302, "INTEGER" ,0,2,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "giim" ,128,1,0,0,0,0,0,0,NULL,&atx[6],NULL,0,&atx[7]} ,
  {410, "Giimport-id" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[139]} ,
  {0, "local" ,128,2,0,0,0,0,0,0,NULL,&atx[8],NULL,0,&atx[9]} ,
  {417, "Object-id" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[10]} ,
  {0, "general" ,128,3,0,0,0,0,0,0,NULL,&atx[10],NULL,0,NULL} ,
  {418, "Dbtag" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[158]} ,
  {315, "CHOICE" ,0,-1,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "data" ,128,1,0,0,0,0,0,0,NULL,&atx[13],NULL,0,&atx[208]} ,
  {420, "SeqFeatData" ,1,0,0,0,0,0,0,0,NULL,&atx[11],&atx[14],0,&atx[215]} ,
  {0, "gene" ,128,0,0,0,0,0,0,0,NULL,&atx[15],NULL,0,&atx[32]} ,
  {404, "Gene-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[16],NULL,0,&atx[107]} ,
  {401, "Gene-ref" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[17],0,&atx[26]} ,
  {0, "locus" ,128,0,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[19]} ,
  {323, "VisibleString" ,0,26,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "allele" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[20]} ,
  {0, "desc" ,128,2,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[21]} ,
  {0, "maploc" ,128,3,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[22]} ,
  {0, "pseudo" ,128,4,0,0,1,0,0,0,&avnx[0],&atx[23],NULL,0,&atx[24]} ,
  {301, "BOOLEAN" ,0,1,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "db" ,128,5,0,1,0,0,0,0,NULL,&atx[27],&atx[25],0,&atx[28]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[26],NULL,0,NULL} ,
  {402, "Dbtag" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,NULL} ,
  {314, "SET OF" ,0,17,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "syn" ,128,6,0,1,0,0,0,0,NULL,&atx[27],&atx[29],0,&atx[30]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "locus-tag" ,128,7,0,1,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {311, "SEQUENCE" ,0,16,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "org" ,128,1,0,0,0,0,0,0,NULL,&atx[33],NULL,0,&atx[76]} ,
  {406, "Org-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[34],NULL,0,&atx[195]} ,
  {401, "Org-ref" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[35],0,&atx[41]} ,
  {0, "taxname" ,128,0,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[36]} ,
  {0, "common" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[37]} ,
  {0, "mod" ,128,2,0,1,0,0,0,0,NULL,&atx[27],&atx[38],0,&atx[39]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "db" ,128,3,0,1,0,0,0,0,NULL,&atx[27],&atx[40],0,&atx[42]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[41],NULL,0,NULL} ,
  {402, "Dbtag" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[45]} ,
  {0, "syn" ,128,4,0,1,0,0,0,0,NULL,&atx[27],&atx[43],0,&atx[44]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "orgname" ,128,5,0,1,0,0,0,0,NULL,&atx[45],NULL,0,NULL} ,
  {403, "OrgName" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[46],0,&atx[48]} ,
  {0, "name" ,128,0,0,1,0,0,0,0,NULL,&atx[11],&atx[47],0,&atx[65]} ,
  {0, "binomial" ,128,0,0,0,0,0,0,0,NULL,&atx[48],NULL,0,&atx[52]} ,
  {404, "BinomialOrgName" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[49],0,&atx[54]} ,
  {0, "genus" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[50]} ,
  {0, "species" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[51]} ,
  {0, "subspecies" ,128,2,0,1,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "virus" ,128,1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[53]} ,
  {0, "hybrid" ,128,2,0,0,0,0,0,0,NULL,&atx[54],NULL,0,&atx[57]} ,
  {405, "MultiOrgName" ,1,0,0,0,0,0,0,0,NULL,&atx[56],&atx[55],0,&atx[59]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[45],NULL,0,NULL} ,
  {312, "SEQUENCE OF" ,0,16,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "namedhybrid" ,128,3,0,0,0,0,0,0,NULL,&atx[48],NULL,0,&atx[58]} ,
  {0, "partial" ,128,4,0,0,0,0,0,0,NULL,&atx[59],NULL,0,NULL} ,
  {406, "PartialOrgName" ,1,0,0,0,0,0,0,0,NULL,&atx[56],&atx[60],0,&atx[68]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[61],NULL,0,NULL} ,
  {408, "TaxElement" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[62],0,NULL} ,
  {0, "fixed-level" ,128,0,0,0,0,0,0,0,NULL,&atx[4],&avnx[1],0,&atx[63]} ,
  {0, "level" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[64]} ,
  {0, "name" ,128,2,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "attrib" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[66]} ,
  {0, "mod" ,128,2,0,1,0,0,0,0,NULL,&atx[56],&atx[67],0,&atx[72]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[68],NULL,0,NULL} ,
  {407, "OrgMod" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[69],0,&atx[61]} ,
  {0, "subtype" ,128,0,0,0,0,0,0,0,NULL,&atx[4],&avnx[5],0,&atx[70]} ,
  {0, "subname" ,128,1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[71]} ,
  {0, "attrib" ,128,2,0,1,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "lineage" ,128,3,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[73]} ,
  {0, "gcode" ,128,4,0,1,0,0,0,0,NULL,&atx[4],NULL,0,&atx[74]} ,
  {0, "mgcode" ,128,5,0,1,0,0,0,0,NULL,&atx[4],NULL,0,&atx[75]} ,
  {0, "div" ,128,6,0,1,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "cdregion" ,128,2,0,0,0,0,0,0,NULL,&atx[77],NULL,0,&atx[106]} ,
  {423, "Cdregion" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[78],0,&atx[142]} ,
  {0, "orf" ,128,0,0,1,0,0,0,0,NULL,&atx[23],NULL,0,&atx[79]} ,
  {0, "frame" ,128,1,0,0,1,0,0,0,&avnx[45],&atx[80],&avnx[41],0,&atx[81]} ,
  {310, "ENUMERATED" ,0,10,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "conflict" ,128,2,0,1,0,0,0,0,NULL,&atx[23],NULL,0,&atx[82]} ,
  {0, "gaps" ,128,3,0,1,0,0,0,0,NULL,&atx[4],NULL,0,&atx[83]} ,
  {0, "mismatch" ,128,4,0,1,0,0,0,0,NULL,&atx[4],NULL,0,&atx[84]} ,
  {0, "code" ,128,5,0,1,0,0,0,0,NULL,&atx[85],NULL,0,&atx[96]} ,
  {403, "Genetic-code" ,1,0,0,0,0,1,0,0,NULL,&atx[27],&atx[86],0,&atx[15]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[11],&atx[87],0,NULL} ,
  {0, "name" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[88]} ,
  {0, "id" ,128,1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[89]} ,
  {0, "ncbieaa" ,128,2,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[90]} ,
  {0, "ncbi8aa" ,128,3,0,0,0,0,0,0,NULL,&atx[91],NULL,0,&atx[92]} ,
  {304, "OCTET STRING" ,0,4,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "ncbistdaa" ,128,4,0,0,0,0,0,0,NULL,&atx[91],NULL,0,&atx[93]} ,
  {0, "sncbieaa" ,128,5,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[94]} ,
  {0, "sncbi8aa" ,128,6,0,0,0,0,0,0,NULL,&atx[91],NULL,0,&atx[95]} ,
  {0, "sncbistdaa" ,128,7,0,0,0,0,0,0,NULL,&atx[91],NULL,0,NULL} ,
  {0, "code-break" ,128,6,0,1,0,0,0,0,NULL,&atx[56],&atx[97],0,&atx[105]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[98],NULL,0,NULL} ,
  {425, "Code-break" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[99],0,&atx[236]} ,
  {0, "loc" ,128,0,0,0,0,0,0,0,NULL,&atx[100],NULL,0,&atx[101]} ,
  {409, "Seq-loc" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[6]} ,
  {0, "aa" ,128,1,0,0,0,0,0,0,NULL,&atx[11],&atx[102],0,NULL} ,
  {0, "ncbieaa" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[103]} ,
  {0, "ncbi8aa" ,128,1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[104]} ,
  {0, "ncbistdaa" ,128,2,0,0,0,0,0,0,NULL,&atx[4],NULL,0,NULL} ,
  {0, "stops" ,128,7,0,1,0,0,0,0,NULL,&atx[4],NULL,0,NULL} ,
  {0, "prot" ,128,3,0,0,0,0,0,0,NULL,&atx[107],NULL,0,&atx[120]} ,
  {405, "Prot-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[108],NULL,0,&atx[33]} ,
  {401, "Prot-ref" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[109],0,&atx[118]} ,
  {0, "name" ,128,0,0,1,0,0,0,0,NULL,&atx[27],&atx[110],0,&atx[111]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "desc" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[112]} ,
  {0, "ec" ,128,2,0,1,0,0,0,0,NULL,&atx[27],&atx[113],0,&atx[114]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "activity" ,128,3,0,1,0,0,0,0,NULL,&atx[27],&atx[115],0,&atx[116]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "db" ,128,4,0,1,0,0,0,0,NULL,&atx[27],&atx[117],0,&atx[119]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[118],NULL,0,NULL} ,
  {402, "Dbtag" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,NULL} ,
  {0, "processed" ,128,5,0,0,1,0,0,0,&avnx[51],&atx[80],&avnx[46],0,NULL} ,
  {0, "rna" ,128,4,0,0,0,0,0,0,NULL,&atx[121],NULL,0,&atx[138]} ,
  {408, "RNA-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[122],NULL,0,&atx[100]} ,
  {401, "RNA-ref" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[123],0,&atx[128]} ,
  {0, "type" ,128,0,0,0,0,0,0,0,NULL,&atx[80],&avnx[52],0,&atx[124]} ,
  {0, "pseudo" ,128,1,0,1,0,0,0,0,NULL,&atx[23],NULL,0,&atx[125]} ,
  {0, "ext" ,128,2,0,1,0,0,0,0,NULL,&atx[11],&atx[126],0,NULL} ,
  {0, "name" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[127]} ,
  {0, "tRNA" ,128,1,0,0,0,0,0,0,NULL,&atx[128],NULL,0,NULL} ,
  {402, "Trna-ext" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[129],0,&atx[137]} ,
  {0, "aa" ,128,0,0,1,0,0,0,0,NULL,&atx[11],&atx[130],0,&atx[134]} ,
  {0, "iupacaa" ,128,0,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[131]} ,
  {0, "ncbieaa" ,128,1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[132]} ,
  {0, "ncbi8aa" ,128,2,0,0,0,0,0,0,NULL,&atx[4],NULL,0,&atx[133]} ,
  {0, "ncbistdaa" ,128,3,0,0,0,0,0,0,NULL,&atx[4],NULL,0,NULL} ,
  {0, "codon" ,128,1,0,1,0,0,0,0,NULL,&atx[27],&atx[135],0,&atx[136]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[4],NULL,0,NULL} ,
  {0, "anticodon" ,128,2,0,1,0,0,0,0,NULL,&atx[137],NULL,0,NULL} ,
  {403, "Seq-loc" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,NULL} ,
  {0, "pub" ,128,5,0,0,0,0,0,0,NULL,&atx[139],NULL,0,&atx[140]} ,
  {411, "Pubdesc" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[189]} ,
  {0, "seq" ,128,6,0,0,0,0,0,0,NULL,&atx[100],NULL,0,&atx[141]} ,
  {0, "imp" ,128,7,0,0,0,0,0,0,NULL,&atx[142],NULL,0,&atx[146]} ,
  {424, "Imp-feat" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[143],0,&atx[98]} ,
  {0, "key" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[144]} ,
  {0, "loc" ,128,1,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[145]} ,
  {0, "descr" ,128,2,0,1,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "region" ,128,8,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[147]} ,
  {0, "comment" ,128,9,0,0,0,0,0,0,NULL,&atx[148],NULL,0,&atx[149]} ,
  {305, "NULL" ,0,5,0,0,0,0,0,0,NULL,NULL,NULL,0,NULL} ,
  {0, "bond" ,128,10,0,0,0,0,0,0,NULL,&atx[80],&avnx[61],0,&atx[150]} ,
  {0, "site" ,128,11,0,0,0,0,0,0,NULL,&atx[80],&avnx[66],0,&atx[151]} ,
  {0, "rsite" ,128,12,0,0,0,0,0,0,NULL,&atx[152],NULL,0,&atx[157]} ,
  {414, "Rsite-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[153],NULL,0,&atx[160]} ,
  {401, "Rsite-ref" ,1,0,0,0,0,1,0,0,NULL,&atx[11],&atx[154],0,&atx[156]} ,
  {0, "str" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[155]} ,
  {0, "db" ,128,1,0,0,0,0,0,0,NULL,&atx[156],NULL,0,NULL} ,
  {402, "Dbtag" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,NULL} ,
  {0, "user" ,128,13,0,0,0,0,0,0,NULL,&atx[158],NULL,0,&atx[159]} ,
  {419, "User-object" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[13]} ,
  {0, "txinit" ,128,14,0,0,0,0,0,0,NULL,&atx[160],NULL,0,&atx[188]} ,
  {415, "Txinit" ,1,0,0,0,0,0,1,0,NULL,&atx[161],NULL,0,&atx[221]} ,
  {401, "Txinit" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[162],0,&atx[167]} ,
  {0, "name" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[163]} ,
  {0, "syn" ,128,1,0,1,0,0,0,0,NULL,&atx[56],&atx[164],0,&atx[165]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "gene" ,128,2,0,1,0,0,0,0,NULL,&atx[56],&atx[166],0,&atx[168]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[167],NULL,0,NULL} ,
  {402, "Gene-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[16],NULL,0,&atx[170]} ,
  {0, "protein" ,128,3,0,1,0,0,0,0,NULL,&atx[56],&atx[169],0,&atx[171]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[170],NULL,0,NULL} ,
  {403, "Prot-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[108],NULL,0,&atx[177]} ,
  {0, "rna" ,128,4,0,1,0,0,0,0,NULL,&atx[56],&atx[172],0,&atx[173]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "expression" ,128,5,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[174]} ,
  {0, "txsystem" ,128,6,0,0,0,0,0,0,NULL,&atx[80],&avnx[93],0,&atx[175]} ,
  {0, "txdescr" ,128,7,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[176]} ,
  {0, "txorg" ,128,8,0,1,0,0,0,0,NULL,&atx[177],NULL,0,&atx[178]} ,
  {404, "Org-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[34],NULL,0,&atx[183]} ,
  {0, "mapping-precise" ,128,9,0,0,1,0,0,0,&avnx[102],&atx[23],NULL,0,&atx[179]} ,
  {0, "location-accurate" ,128,10,0,0,1,0,0,0,&avnx[103],&atx[23],NULL,0,&atx[180]} ,
  {0, "inittype" ,128,11,0,1,0,0,0,0,NULL,&atx[80],&avnx[104],0,&atx[181]} ,
  {0, "evidence" ,128,12,0,1,0,0,0,0,NULL,&atx[27],&atx[182],0,NULL} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[183],NULL,0,NULL} ,
  {405, "Tx-evidence" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[184],0,NULL} ,
  {0, "exp-code" ,128,0,0,0,0,0,0,0,NULL,&atx[80],&avnx[108],0,&atx[185]} ,
  {0, "expression-system" ,128,1,0,0,1,0,0,0,&avnx[127],&atx[80],&avnx[120],0,&atx[186]} ,
  {0, "low-prec-data" ,128,2,0,0,1,0,0,0,&avnx[128],&atx[23],NULL,0,&atx[187]} ,
  {0, "from-homolog" ,128,3,0,0,1,0,0,0,&avnx[129],&atx[23],NULL,0,NULL} ,
  {0, "num" ,128,15,0,0,0,0,0,0,NULL,&atx[189],NULL,0,&atx[190]} ,
  {412, "Numbering" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[193]} ,
  {0, "psec-str" ,128,16,0,0,0,0,0,0,NULL,&atx[80],&avnx[130],0,&atx[191]} ,
  {0, "non-std-residue" ,128,17,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[192]} ,
  {0, "het" ,128,18,0,0,0,0,0,0,NULL,&atx[193],NULL,0,&atx[194]} ,
  {413, "Heterogen" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[152]} ,
  {0, "biosrc" ,128,19,0,0,0,0,0,0,NULL,&atx[195],NULL,0,NULL} ,
  {407, "BioSource" ,1,0,0,0,0,0,1,0,NULL,&atx[196],NULL,0,&atx[121]} ,
  {401, "BioSource" ,1,0,0,0,0,1,0,0,NULL,&atx[31],&atx[197],0,&atx[200]} ,
  {0, "genome" ,128,0,0,0,1,0,0,0,&avnx[153],&atx[4],&avnx[133],0,&atx[198]} ,
  {0, "origin" ,128,1,0,0,1,0,0,0,&avnx[161],&atx[4],&avnx[154],0,&atx[199]} ,
  {0, "org" ,128,2,0,0,0,0,0,0,NULL,&atx[200],NULL,0,&atx[201]} ,
  {402, "Org-ref" ,1,0,0,0,0,0,1,0,NULL,&atx[34],NULL,0,&atx[203]} ,
  {0, "subtype" ,128,3,0,1,0,0,0,0,NULL,&atx[56],&atx[202],0,&atx[207]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[203],NULL,0,NULL} ,
  {403, "SubSource" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[204],0,NULL} ,
  {0, "subtype" ,128,0,0,0,0,0,0,0,NULL,&atx[4],&avnx[162],0,&atx[205]} ,
  {0, "name" ,128,1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[206]} ,
  {0, "attrib" ,128,2,0,1,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "is-focus" ,128,4,0,1,0,0,0,0,NULL,&atx[148],NULL,0,NULL} ,
  {0, "partial" ,128,2,0,1,0,0,0,0,NULL,&atx[23],NULL,0,&atx[209]} ,
  {0, "except" ,128,3,0,1,0,0,0,0,NULL,&atx[23],NULL,0,&atx[210]} ,
  {0, "comment" ,128,4,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[211]} ,
  {0, "product" ,128,5,0,1,0,0,0,0,NULL,&atx[100],NULL,0,&atx[212]} ,
  {0, "location" ,128,6,0,0,0,0,0,0,NULL,&atx[100],NULL,0,&atx[213]} ,
  {0, "qual" ,128,7,0,1,0,0,0,0,NULL,&atx[56],&atx[214],0,&atx[218]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[215],NULL,0,NULL} ,
  {421, "Gb-qual" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[216],0,&atx[225]} ,
  {0, "qual" ,128,0,0,0,0,0,0,0,NULL,&atx[18],NULL,0,&atx[217]} ,
  {0, "val" ,128,1,0,0,0,0,0,0,NULL,&atx[18],NULL,0,NULL} ,
  {0, "title" ,128,8,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[219]} ,
  {0, "ext" ,128,9,0,1,0,0,0,0,NULL,&atx[158],NULL,0,&atx[220]} ,
  {0, "cit" ,128,10,0,1,0,0,0,0,NULL,&atx[221],NULL,0,&atx[222]} ,
  {416, "Pub-set" ,1,0,0,0,0,0,1,0,NULL,NULL,NULL,0,&atx[8]} ,
  {0, "exp-ev" ,128,11,0,1,0,0,0,0,NULL,&atx[80],&avnx[199],0,&atx[223]} ,
  {0, "xref" ,128,12,0,1,0,0,0,0,NULL,&atx[27],&atx[224],0,&atx[228]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[225],NULL,0,NULL} ,
  {422, "SeqFeatXref" ,1,0,0,0,0,0,0,0,NULL,&atx[31],&atx[226],0,&atx[77]} ,
  {0, "id" ,128,0,0,1,0,0,0,0,NULL,&atx[2],NULL,0,&atx[227]} ,
  {0, "data" ,128,1,0,1,0,0,0,0,NULL,&atx[13],NULL,0,NULL} ,
  {0, "dbxref" ,128,13,0,1,0,0,0,0,NULL,&atx[27],&atx[229],0,&atx[230]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[10],NULL,0,NULL} ,
  {0, "pseudo" ,128,14,0,1,0,0,0,0,NULL,&atx[23],NULL,0,&atx[231]} ,
  {0, "except-text" ,128,15,0,1,0,0,0,0,NULL,&atx[18],NULL,0,&atx[232]} ,
  {0, "ids" ,128,16,0,1,0,0,0,0,NULL,&atx[27],&atx[233],0,&atx[234]} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[2],NULL,0,NULL} ,
  {0, "exts" ,128,17,0,1,0,0,0,0,NULL,&atx[27],&atx[235],0,NULL} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[158],NULL,0,NULL} ,
  {426, "Genetic-code-table" ,1,0,0,0,0,0,0,0,NULL,&atx[27],&atx[237],0,NULL} ,
  {0, NULL,1,-1,0,0,0,0,0,0,NULL,&atx[85],NULL,0,NULL} };

static AsnModule ampx[8] = {
  { "NCBI-Seqfeat" , "asnfeat.h13",&atx[0],NULL,&ampx[1],0,0} ,
  { "NCBI-Rsite" , NULL,&atx[153],NULL,&ampx[2],0,0} ,
  { "NCBI-RNA" , NULL,&atx[122],NULL,&ampx[3],0,0} ,
  { "NCBI-Gene" , NULL,&atx[16],NULL,&ampx[4],0,0} ,
  { "NCBI-Organism" , NULL,&atx[34],NULL,&ampx[5],0,0} ,
  { "NCBI-BioSource" , NULL,&atx[196],NULL,&ampx[6],0,0} ,
  { "NCBI-Protein" , NULL,&atx[108],NULL,&ampx[7],0,0} ,
  { "NCBI-TxInit" , NULL,&atx[161],NULL,NULL,0,0} };

static AsnValxNodePtr avn = avnx;
static AsnTypePtr at = atx;
static AsnModulePtr amp = ampx;



/**************************************************
*
*    Defines for Module NCBI-Seqfeat
*
**************************************************/

#define SEQ_FEAT &at[0]
#define SEQ_FEAT_id &at[1]
#define SEQ_FEAT_data &at[12]
#define SEQ_FEAT_partial &at[208]
#define SEQ_FEAT_except &at[209]
#define SEQ_FEAT_comment &at[210]
#define SEQ_FEAT_product &at[211]
#define SEQ_FEAT_location &at[212]
#define SEQ_FEAT_qual &at[213]
#define SEQ_FEAT_qual_E &at[214]
#define SEQ_FEAT_title &at[218]
#define SEQ_FEAT_ext &at[219]
#define SEQ_FEAT_cit &at[220]
#define SEQ_FEAT_exp_ev &at[222]
#define SEQ_FEAT_xref &at[223]
#define SEQ_FEAT_xref_E &at[224]
#define SEQ_FEAT_dbxref &at[228]
#define SEQ_FEAT_dbxref_E &at[229]
#define SEQ_FEAT_pseudo &at[230]
#define SEQ_FEAT_except_text &at[231]
#define SEQ_FEAT_ids &at[232]
#define SEQ_FEAT_ids_E &at[233]
#define SEQ_FEAT_exts &at[234]
#define SEQ_FEAT_exts_E &at[235]

#define FEAT_ID &at[2]
#define FEAT_ID_gibb &at[3]
#define FEAT_ID_giim &at[5]
#define FEAT_ID_local &at[7]
#define FEAT_ID_general &at[9]

#define GENETIC_CODE &at[85]
#define GENETIC_CODE_E &at[86]
#define GENETIC_CODE_E_name &at[87]
#define GENETIC_CODE_E_id &at[88]
#define GENETIC_CODE_E_ncbieaa &at[89]
#define GENETIC_CODE_E_ncbi8aa &at[90]
#define GENETIC_CODE_E_ncbistdaa &at[92]
#define GENETIC_CODE_E_sncbieaa &at[93]
#define GENETIC_CODE_E_sncbi8aa &at[94]
#define GENETIC_CODE_E_sncbistdaa &at[95]

#define SEQFEATDATA &at[13]
#define SEQFEATDATA_gene &at[14]
#define SEQFEATDATA_org &at[32]
#define SEQFEATDATA_cdregion &at[76]
#define SEQFEATDATA_prot &at[106]
#define SEQFEATDATA_rna &at[120]
#define SEQFEATDATA_pub &at[138]
#define SEQFEATDATA_seq &at[140]
#define SEQFEATDATA_imp &at[141]
#define SEQFEATDATA_region &at[146]
#define SEQFEATDATA_comment &at[147]
#define SEQFEATDATA_bond &at[149]
#define SEQFEATDATA_site &at[150]
#define SEQFEATDATA_rsite &at[151]
#define SEQFEATDATA_user &at[157]
#define SEQFEATDATA_txinit &at[159]
#define SEQFEATDATA_num &at[188]
#define SEQFEATDATA_psec_str &at[190]
#define SEQFEATDATA_non_std_residue &at[191]
#define SEQFEATDATA_het &at[192]
#define SEQFEATDATA_biosrc &at[194]

#define GB_QUAL &at[215]
#define GB_QUAL_qual &at[216]
#define GB_QUAL_val &at[217]

#define SEQFEATXREF &at[225]
#define SEQFEATXREF_id &at[226]
#define SEQFEATXREF_data &at[227]

#define CDREGION &at[77]
#define CDREGION_orf &at[78]
#define CDREGION_frame &at[79]
#define CDREGION_conflict &at[81]
#define CDREGION_gaps &at[82]
#define CDREGION_mismatch &at[83]
#define CDREGION_code &at[84]
#define CDREGION_code_break &at[96]
#define CDREGION_code_break_E &at[97]
#define CDREGION_stops &at[105]

#define IMP_FEAT &at[142]
#define IMP_FEAT_key &at[143]
#define IMP_FEAT_loc &at[144]
#define IMP_FEAT_descr &at[145]

#define CODE_BREAK &at[98]
#define CODE_BREAK_loc &at[99]
#define CODE_BREAK_aa &at[101]
#define CODE_BREAK_aa_ncbieaa &at[102]
#define CODE_BREAK_aa_ncbi8aa &at[103]
#define CODE_BREAK_aa_ncbistdaa &at[104]

#define GENETIC_CODE_TABLE &at[236]
#define GENETIC_CODE_TABLE_E &at[237]


/**************************************************
*
*    Defines for Module NCBI-Rsite
*
**************************************************/

#define RSITE_REF &at[153]
#define RSITE_REF_str &at[154]
#define RSITE_REF_db &at[155]


/**************************************************
*
*    Defines for Module NCBI-RNA
*
**************************************************/

#define RNA_REF &at[122]
#define RNA_REF_type &at[123]
#define RNA_REF_pseudo &at[124]
#define RNA_REF_ext &at[125]
#define RNA_REF_ext_name &at[126]
#define RNA_REF_ext_tRNA &at[127]

#define TRNA_EXT &at[128]
#define TRNA_EXT_aa &at[129]
#define TRNA_EXT_aa_iupacaa &at[130]
#define TRNA_EXT_aa_ncbieaa &at[131]
#define TRNA_EXT_aa_ncbi8aa &at[132]
#define TRNA_EXT_aa_ncbistdaa &at[133]
#define TRNA_EXT_codon &at[134]
#define TRNA_EXT_codon_E &at[135]
#define TRNA_EXT_anticodon &at[136]


/**************************************************
*
*    Defines for Module NCBI-Gene
*
**************************************************/

#define GENE_REF &at[16]
#define GENE_REF_locus &at[17]
#define GENE_REF_allele &at[19]
#define GENE_REF_desc &at[20]
#define GENE_REF_maploc &at[21]
#define GENE_REF_pseudo &at[22]
#define GENE_REF_db &at[24]
#define GENE_REF_db_E &at[25]
#define GENE_REF_syn &at[28]
#define GENE_REF_syn_E &at[29]
#define GENE_REF_locus_tag &at[30]


/**************************************************
*
*    Defines for Module NCBI-Organism
*
**************************************************/

#define ORG_REF &at[34]
#define ORG_REF_taxname &at[35]
#define ORG_REF_common &at[36]
#define ORG_REF_mod &at[37]
#define ORG_REF_mod_E &at[38]
#define ORG_REF_db &at[39]
#define ORG_REF_db_E &at[40]
#define ORG_REF_syn &at[42]
#define ORG_REF_syn_E &at[43]
#define ORG_REF_orgname &at[44]

#define ORGNAME &at[45]
#define ORGNAME_name &at[46]
#define ORGNAME_name_binomial &at[47]
#define ORGNAME_name_virus &at[52]
#define ORGNAME_name_hybrid &at[53]
#define ORGNAME_name_namedhybrid &at[57]
#define ORGNAME_name_partial &at[58]
#define ORGNAME_attrib &at[65]
#define ORGNAME_mod &at[66]
#define ORGNAME_mod_E &at[67]
#define ORGNAME_lineage &at[72]
#define ORGNAME_gcode &at[73]
#define ORGNAME_mgcode &at[74]
#define ORGNAME_div &at[75]

#define BINOMIALORGNAME &at[48]
#define BINOMIALORGNAME_genus &at[49]
#define BINOMIALORGNAME_species &at[50]
#define BINOMIALORGNAME_subspecies &at[51]

#define MULTIORGNAME &at[54]
#define MULTIORGNAME_E &at[55]

#define PARTIALORGNAME &at[59]
#define PARTIALORGNAME_E &at[60]

#define ORGMOD &at[68]
#define ORGMOD_subtype &at[69]
#define ORGMOD_subname &at[70]
#define ORGMOD_attrib &at[71]

#define TAXELEMENT &at[61]
#define TAXELEMENT_fixed_level &at[62]
#define TAXELEMENT_level &at[63]
#define TAXELEMENT_name &at[64]


/**************************************************
*
*    Defines for Module NCBI-BioSource
*
**************************************************/

#define BIOSOURCE &at[196]
#define BIOSOURCE_genome &at[197]
#define BIOSOURCE_origin &at[198]
#define BIOSOURCE_org &at[199]
#define BIOSOURCE_subtype &at[201]
#define BIOSOURCE_subtype_E &at[202]
#define BIOSOURCE_is_focus &at[207]

#define SUBSOURCE &at[203]
#define SUBSOURCE_subtype &at[204]
#define SUBSOURCE_name &at[205]
#define SUBSOURCE_attrib &at[206]


/**************************************************
*
*    Defines for Module NCBI-Protein
*
**************************************************/

#define PROT_REF &at[108]
#define PROT_REF_name &at[109]
#define PROT_REF_name_E &at[110]
#define PROT_REF_desc &at[111]
#define PROT_REF_ec &at[112]
#define PROT_REF_ec_E &at[113]
#define PROT_REF_activity &at[114]
#define PROT_REF_activity_E &at[115]
#define PROT_REF_db &at[116]
#define PROT_REF_db_E &at[117]
#define PROT_REF_processed &at[119]


/**************************************************
*
*    Defines for Module NCBI-TxInit
*
**************************************************/

#define TXINIT &at[161]
#define TXINIT_name &at[162]
#define TXINIT_syn &at[163]
#define TXINIT_syn_E &at[164]
#define TXINIT_gene &at[165]
#define TXINIT_gene_E &at[166]
#define TXINIT_protein &at[168]
#define TXINIT_protein_E &at[169]
#define TXINIT_rna &at[171]
#define TXINIT_rna_E &at[172]
#define TXINIT_expression &at[173]
#define TXINIT_txsystem &at[174]
#define TXINIT_txdescr &at[175]
#define TXINIT_txorg &at[176]
#define TXINIT_mapping_precise &at[178]
#define TXINIT_location_accurate &at[179]
#define TXINIT_inittype &at[180]
#define TXINIT_evidence &at[181]
#define TXINIT_evidence_E &at[182]

#define TX_EVIDENCE &at[183]
#define TX_EVIDENCE_exp_code &at[184]
#define TX_EVIDENCE_expression_system &at[185]
#define TX_EVIDENCE_low_prec_data &at[186]
#define TX_EVIDENCE_from_homolog &at[187]
